@@ -12,7 +12,7 @@ sub loader {
 
 =head1
 
-Module::Setup::Flavor::Default - default flavor
+Module::Setup::Flavor::CodeRepos - coderepos flavor
 
 =head1 SYNOPSIS
 
@@ -33,8 +33,6 @@ template: |
   1;
   __END__
 
-  =encoding utf8
-
   =head1 NAME
 
   [% module %] -
